package com.ruixuan.isc.controller;

import com.alibaba.fastjson.JSONObject;
import com.ruixuan.common.core.controller.BaseController;
import com.ruixuan.common.core.domain.AjaxResult;
import com.ruixuan.common.core.page.TableDataInfo;
import com.ruixuan.isc.entity.KuaishouPromoter;
import com.ruixuan.isc.service.IKuaishouPromoterService;
import com.ruixuan.isc.utils.Tess4jClient;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 快手达人 信息Controller
 *
 * @author ruoyi
 * @date 2023-02-03
 */

@Api(tags = "快手达人")
@RestController
@RequestMapping("/kuaishou/promoter")
public class KuaishouPromoterController extends BaseController {
    @Autowired
    private IKuaishouPromoterService kuaishouPromoterService;

    @Value("${tessdata.path}")
    private String path;

    /**
     * 查询快手达人 信息列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询快手达人")
    public TableDataInfo list(@ApiParam("创建人ID") @RequestParam(value = "userId", required = true) Long userId,
                              @ApiParam("达人ID") @RequestParam(value = "promoterId", required = false) Long promoterId,
                              @ApiParam("达人名称") @RequestParam(value = "promoterNickName", required = false) String promoterNickName,
                              @ApiParam("排序参数") @RequestParam(value = "parameter", required = false) String parameter,
                              @ApiParam("正序倒叙") @RequestParam(value = "orderBy", required = false) String orderBy

    ) {
        List<KuaishouPromoter> list = kuaishouPromoterService.selectKuaishouPromoterList(userId, promoterId, promoterNickName, parameter, orderBy);
        return getDataTable(list);
    }

    /**
     * 达人公海
     */
    @GetMapping("/list2")
    @ApiOperation(value = "达人公海")
    public TableDataInfo list2(@ApiParam("达人ID") @RequestParam(value = "promoterId", required = false) Long promoterId,
                               @ApiParam("达人名称") @RequestParam(value = "promoterNickName", required = false) String promoterNickName,
                               @ApiParam("排序参数") @RequestParam(value = "parameter", required = false) String parameter,
                               @ApiParam("正序倒叙") @RequestParam(value = "orderBy", required = false) String orderBy

    ) {
        List<KuaishouPromoter> list = kuaishouPromoterService.selectKuaishouPromoterList2(promoterId, promoterNickName, parameter, orderBy);
        return getDataTable(list);
    }

    /**
     * 获取快手达人 信息详细信息
     */
    @GetMapping(value = "/getById")
    @ApiOperation(value = "获取快手达人信息详细信息")
    public AjaxResult getById(@ApiParam("主键") @RequestParam(value = "id", required = true) Long id) {
        return AjaxResult.success(kuaishouPromoterService.selectKuaishouPromoterById(id));
    }

    /**
     * 获取快手达人信息
     */
    @GetMapping(value = "/supplementInfo")
    @ApiOperation(value = "补全失败的数据")
    public String supplementInfo() {
        return kuaishouPromoterService.supplementInfo();
    }

    /**
     * 获取快手达人信息
     */
    @GetMapping(value = "/getPromoterInfo")
    @ApiOperation(value = "获取快手达人短视频信息")
    public AjaxResult getPromoterInfo(@ApiParam("达人ID") @RequestParam(value = "promoterId", required = true) Long promoterId) {
        return kuaishouPromoterService.getPromoterInfo(promoterId);
    }


    /**
     * 获取快手达人信息
     */
    @GetMapping(value = "/getOnlyPromoterInfo")
    @ApiOperation(value = "只获取达人信息")
    public AjaxResult getOnlyPromoterInfo(@ApiParam("达人ID") @RequestParam(value = "promoterId", required = true) Long promoterId) {
        return AjaxResult.success(kuaishouPromoterService.getOnlyPromoterInfo(promoterId));
    }

    /**
     * 新增快手达人 信息
     */
    @PostMapping(value = "/add")
    @ApiOperation(value = "新增快手达人")
    public AjaxResult add(@RequestBody KuaishouPromoter kuaishouPromoter) {
        return toAjax2(kuaishouPromoterService.insertKuaishouPromoter(kuaishouPromoter));
    }

    /**
     * 修改快手达人 信息
     */
    @PostMapping(value = "/edit")
    @ApiOperation(value = "修改快手达人")
    public AjaxResult edit(@RequestBody KuaishouPromoter kuaishouPromoter) {
        return toAjax(kuaishouPromoterService.updateKuaishouPromoter(kuaishouPromoter));
    }

    /**
     * 删除快手达人 信息
     */
    @GetMapping("/deleteById")
    @ApiOperation(value = "删除快手达人")
    public AjaxResult deleteById(@ApiParam("主键") @RequestParam(value = "id", required = true) Long id,
                                 @ApiParam("操作人ID") @RequestParam(value = "userId", required = true) Long userId
    ) {
        return toAjax(kuaishouPromoterService.deleteKuaishouPromoterById(id, userId));
    }


    /**
     * 读取图片文字信息
     */
    @PostMapping(value = "/readImage")
    @ApiOperation(value = "读取图片文字信息")
    public JSONObject readImage(@RequestParam("file") MultipartFile file) {
        JSONObject result = new JSONObject();
        try {
            result.put("code", 0);
            result.put("message", "success");
            result.put("data", Tess4jClient.getWords(file, path));
            return result;
        } catch (Exception e) {
            e.printStackTrace();
        }
        result.put("code", -1);
        result.put("message", "fail");
        return result;
    }
}
